@@ -312,18 +312,10 @@ been replaced by a new file in the meantime.
 The parameters C<check_interval> and C<signal> limit the number of physical 
 file system checks, simililarily as with C<change_detected()>.
 
-=head1 SEE ALSO
-
-=head1 AUTHOR
-
-    Mike Schilli, <log4perl@perlmeister.com>
-
-=cut
-
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2003 by Mike Schilli E<lt>m@perlmeister.comE<gt> and Kevin Goess
-E<lt>cpan@goess.orgE<gt>.
+Copyright 2002-2009 by Mike Schilli E<lt>m@perlmeister.comE<gt> 
+and Kevin Goess E<lt>cpan@goess.orgE<gt>.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
